# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class SecureAgentSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'org_id': 'str',
        'application_service_ids': 'list[str]',
        'connectors': 'list[SecureAgentConnector]'
    }

    attribute_map = {
        'name': 'name',
        'org_id': 'org_id',
        'application_service_ids': 'application_service_ids',
        'connectors': 'connectors'
    }

    def __init__(self, name=None, org_id=None, application_service_ids=None, connectors=None, local_vars_configuration=None):  # noqa: E501
        """SecureAgentSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._org_id = None
        self._application_service_ids = None
        self._connectors = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.org_id = org_id
        if application_service_ids is not None:
            self.application_service_ids = application_service_ids
        if connectors is not None:
            self.connectors = connectors

    @property
    def name(self):
        """Gets the name of this SecureAgentSpec.  # noqa: E501

        A descriptive name for the secure agent  # noqa: E501

        :return: The name of this SecureAgentSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SecureAgentSpec.

        A descriptive name for the secure agent  # noqa: E501

        :param name: The name of this SecureAgentSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def org_id(self):
        """Gets the org_id of this SecureAgentSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this SecureAgentSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this SecureAgentSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this SecureAgentSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def application_service_ids(self):
        """Gets the application_service_ids of this SecureAgentSpec.  # noqa: E501

        The list of application service ids associated with this secure agent  # noqa: E501

        :return: The application_service_ids of this SecureAgentSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._application_service_ids

    @application_service_ids.setter
    def application_service_ids(self, application_service_ids):
        """Sets the application_service_ids of this SecureAgentSpec.

        The list of application service ids associated with this secure agent  # noqa: E501

        :param application_service_ids: The application_service_ids of this SecureAgentSpec.  # noqa: E501
        :type: list[str]
        """

        self._application_service_ids = application_service_ids

    @property
    def connectors(self):
        """Gets the connectors of this SecureAgentSpec.  # noqa: E501

        The list of connectors this agent uses to establish tunnels with the infrastructure   # noqa: E501

        :return: The connectors of this SecureAgentSpec.  # noqa: E501
        :rtype: list[SecureAgentConnector]
        """
        return self._connectors

    @connectors.setter
    def connectors(self, connectors):
        """Sets the connectors of this SecureAgentSpec.

        The list of connectors this agent uses to establish tunnels with the infrastructure   # noqa: E501

        :param connectors: The connectors of this SecureAgentSpec.  # noqa: E501
        :type: list[SecureAgentConnector]
        """

        self._connectors = connectors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecureAgentSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SecureAgentSpec):
            return True

        return self.to_dict() != other.to_dict()
