# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ConnectorSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'name_slug': 'str',
        'org_id': 'str',
        'connector_type': 'str',
        'service_account_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'name_slug': 'name_slug',
        'org_id': 'org_id',
        'connector_type': 'connector_type',
        'service_account_id': 'service_account_id'
    }

    def __init__(self, name=None, name_slug=None, org_id=None, connector_type=None, service_account_id=None, local_vars_configuration=None):  # noqa: E501
        """ConnectorSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._name_slug = None
        self._org_id = None
        self._connector_type = None
        self._service_account_id = None
        self.discriminator = None

        self.name = name
        if name_slug is not None:
            self.name_slug = name_slug
        self.org_id = org_id
        self.connector_type = connector_type
        if service_account_id is not None:
            self.service_account_id = service_account_id

    @property
    def name(self):
        """Gets the name of this ConnectorSpec.  # noqa: E501

        A descriptive name for the connector  # noqa: E501

        :return: The name of this ConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConnectorSpec.

        A descriptive name for the connector  # noqa: E501

        :param name: The name of this ConnectorSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def name_slug(self):
        """Gets the name_slug of this ConnectorSpec.  # noqa: E501

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :return: The name_slug of this ConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._name_slug

    @name_slug.setter
    def name_slug(self, name_slug):
        """Sets the name_slug of this ConnectorSpec.

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :param name_slug: The name_slug of this ConnectorSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and len(name_slug) > 20):
            raise ValueError("Invalid value for `name_slug`, length must be less than or equal to `20`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and not re.search(r'^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$', name_slug)):  # noqa: E501
            raise ValueError(r"Invalid value for `name_slug`, must be a follow pattern or equal to `/^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$/`")  # noqa: E501

        self._name_slug = name_slug

    @property
    def org_id(self):
        """Gets the org_id of this ConnectorSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this ConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this ConnectorSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this ConnectorSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def connector_type(self):
        """Gets the connector_type of this ConnectorSpec.  # noqa: E501

        The type of the connector  # noqa: E501

        :return: The connector_type of this ConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._connector_type

    @connector_type.setter
    def connector_type(self, connector_type):
        """Sets the connector_type of this ConnectorSpec.

        The type of the connector  # noqa: E501

        :param connector_type: The connector_type of this ConnectorSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_type is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_type`, must not be `None`")  # noqa: E501
        allowed_values = ["agent", "ipsec"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and connector_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `connector_type` ({0}), must be one of {1}"  # noqa: E501
                .format(connector_type, allowed_values)
            )

        self._connector_type = connector_type

    @property
    def service_account_id(self):
        """Gets the service_account_id of this ConnectorSpec.  # noqa: E501

        Service account user GUID used to deploy the connector  # noqa: E501

        :return: The service_account_id of this ConnectorSpec.  # noqa: E501
        :rtype: str
        """
        return self._service_account_id

    @service_account_id.setter
    def service_account_id(self, service_account_id):
        """Sets the service_account_id of this ConnectorSpec.

        Service account user GUID used to deploy the connector  # noqa: E501

        :param service_account_id: The service_account_id of this ConnectorSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) > 40):
            raise ValueError("Invalid value for `service_account_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) < 1):
            raise ValueError("Invalid value for `service_account_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._service_account_id = service_account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectorSpec):
            return True

        return self.to_dict() != other.to_dict()
